==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/battle/rgss/Game_Enemy.rb <==
#==============================================================================
#  Game_Enemy
#------------------------------------------------------------------------------
# Gl~[C
# SP̃RXgӎ悤ɏC
# Copyright (C) 2005 fukuyama
#==============================================================================

class Game_Enemy
  #--------------------------------------------------------------------------
  #  ANV쐬
  #--------------------------------------------------------------------------
  def make_action
    # JgANVNA
    self.current_action.clear
    # Ȃꍇ
    unless self.movable?
      # \bhI
      return
    end
    # ݗLȃANV𒊏o
    available_actions = []
    rating_max = 0
    for action in self.actions
      # ^[ mF
      n = $game_temp.battle_turn
      a = action.condition_turn_a
      b = action.condition_turn_b
      if (b == 0 and n != a) or
         (b > 0 and (n < 1 or n < a or n % b != a % b))
        next
      end
      # HP mF
      if self.hp * 100.0 / self.maxhp > action.condition_hp
        next
      end
      # x mF
      if $game_party.max_level < action.condition_level
        next
      end
      # XCb` mF
      switch_id = action.condition_switch_id
      if switch_id > 0 and $game_switches[switch_id] == false
        next
      end
      # XL mF
      if action.kind == 1
        # SP Ȃꍇ͎gps
        if $data_skills[action.skill_id].sp_cost > self.sp
          next
        end
      end
      # ɊY : ̃ANVǉ
      available_actions.push(action)
      if action.rating > rating_max
        rating_max = action.rating
      end
    end
    # ő̃[eBOl 3 ƂčvvZ (0 ȉ͏O)
    ratings_total = 0
    for action in available_actions
      if action.rating > rating_max - 3
        ratings_total += action.rating - (rating_max - 3)
      end
    end
    # [eBO̍v 0 ł͂Ȃꍇ
    if ratings_total > 0
      # 쐬
      value = rand(ratings_total)
      # 쐬ɑΉ̂JgANVɐݒ
      for action in available_actions
        if action.rating > rating_max - 3
          if value < action.rating - (rating_max - 3)
            self.current_action.kind = action.kind
            self.current_action.basic = action.basic
            self.current_action.skill_id = action.skill_id
            self.current_action.decide_random_target_for_enemy
            return
          else
            value -= action.rating - (rating_max - 3)
          end
        end
      end
    end
  end
end

==> DQScriptsDemo_0_3_1.zip: DQScriptsDemo_0_3_1/rgss-lib/dq/battle/rgss/Game_Enemy.rb <==
#==============================================================================
#  Game_Enemy
#------------------------------------------------------------------------------
# Gl~[C
# SP̃RXgӎ悤ɏC
# Copyright (C) 2005 fukuyama
#==============================================================================

class Game_Enemy
  #--------------------------------------------------------------------------
  #  og Y W̎擾
  #--------------------------------------------------------------------------
  def screen_y
    return $data_troops[@troop_id].members[@member_index].y + ::DQ::GAME_ENEMY_SCREEN_Y
  end
  #--------------------------------------------------------------------------
  #  ANV쐬
  #--------------------------------------------------------------------------
  def make_action
    # JgANVNA
    self.current_action.clear
    # Ȃꍇ
    unless self.movable?
      # \bhI
      return
    end
    # ݗLȃANV𒊏o
    available_actions = []
    rating_max = 0
    for action in self.actions
      # ^[ mF
      n = $game_temp.battle_turn
      a = action.condition_turn_a
      b = action.condition_turn_b
      if (b == 0 and n != a) or
         (b > 0 and (n < 1 or n < a or n % b != a % b))
        next
      end
      # HP mF
      if self.hp * 100.0 / self.maxhp > action.condition_hp
        next
      end
      # x mF
      if $game_party.max_level < action.condition_level
        next
      end
      # XCb` mF
      switch_id = action.condition_switch_id
      if switch_id > 0 and $game_switches[switch_id] == false
        next
      end
      # XL mF
      if action.kind == 1
        # SP Ȃꍇ͎gps
        if $data_skills[action.skill_id].sp_cost > self.sp
          next
        end
      end
      # ɊY : ̃ANVǉ
      available_actions.push(action)
      if action.rating > rating_max
        rating_max = action.rating
      end
    end
    # ő̃[eBOl 3 ƂčvvZ (0 ȉ͏O)
    ratings_total = 0
    for action in available_actions
      if action.rating > rating_max - 3
        ratings_total += action.rating - (rating_max - 3)
      end
    end
    # [eBO̍v 0 ł͂Ȃꍇ
    if ratings_total > 0
      # 쐬
      value = rand(ratings_total)
      # 쐬ɑΉ̂JgANVɐݒ
      for action in available_actions
        if action.rating > rating_max - 3
          if value < action.rating - (rating_max - 3)
            self.current_action.kind = action.kind
            self.current_action.basic = action.basic
            self.current_action.skill_id = action.skill_id
            self.current_action.decide_random_target_for_enemy
            return
          else
            value -= action.rating - (rating_max - 3)
          end
        end
      end
    end
  end
end
